@@ -208,7 +208,7 @@ void Engine::startMetaUpdater(bool reload)
 	  else
 	  {
 	    int index_cur = listSources.indexOf(mediaObjectForMetaInfos->currentSource());
-	    qDebug()<<index_cur<<"\t"<<lastUpdated;
+	    //qDebug()<<index_cur<<"\t"<<lastUpdated;
 	    if(index_cur>=lastUpdated || index_cur==-1)
 	    {
 	      mediaObjectForMetaInfos->setCurrentSource(listSources.at(lastUpdated+1));
