@@ -8,7 +8,12 @@ SettingsDialog::SettingsDialog()
   scrollW = new QWidget(scrArea);
   scrArea->setWidgetResizable(true);
   scrollLayout = new QVBoxLayout(scrollW);
+  //configLayout = new QVBoxLayout(this);
+  #ifdef Q_WS_MAEMO
+  configLayout = new QHBoxLayout(this);
+  #else
   configLayout = new QVBoxLayout(this);
+  #endif
   
   playlistBox = new QGroupBox(scrollW);
   playlistBox->setTitle(tr("Playlist"));
@@ -35,16 +40,23 @@ SettingsDialog::SettingsDialog()
   
   updateOnAddingOrPlaying = new QButtonGroup(scrollW);
   
+  labelMetadata = new QLabel(scrollW);
+  labelMetadata->setText(tr("Retrieve metadata:"));
+  
   updateOnAdding = new QRadioButton(scrollW);
-  updateOnAdding->setText(tr("Auto update"));
+  updateOnAdding->setText(tr("Playlist"));
   updateOnPlaying = new QRadioButton(scrollW);
-  updateOnPlaying->setText(tr("Update on playing"));
+  updateOnPlaying->setText(tr("Played song"));
   
   updateOnAddingOrPlaying->addButton(updateOnAdding);
   updateOnAddingOrPlaying->addButton(updateOnPlaying);
-
-  playlistLayout->addWidget(updateOnAdding);
-  playlistLayout->addWidget(updateOnPlaying);
+  playlistLayout->addWidget(labelMetadata);
+  //playlistLayout->addWidget(updateOnAdding);
+  //playlistLayout->addWidget(updateOnPlaying);
+  tagsOptLayout = new QHBoxLayout();
+  tagsOptLayout->addWidget(updateOnAdding);
+  tagsOptLayout->addWidget(updateOnPlaying);
+  playlistLayout->addLayout(tagsOptLayout);
   
   savePlaylistOnQuit = new QCheckBox(scrollW);
   savePlaylistOnQuit->setText(tr("Save playlist on quit"));
@@ -95,6 +107,9 @@ SettingsDialog::SettingsDialog()
   
   dialogButtons = new QDialogButtonBox(this);
   dialogButtons->setStandardButtons(QDialogButtonBox::Ok|QDialogButtonBox::Cancel);
+  #ifdef Q_WS_MAEMO
+  dialogButtons->setOrientation(Qt::Vertical);
+  #endif
   
   configLayout->addWidget(scrArea);
   configLayout->addWidget(dialogButtons);
@@ -104,6 +119,7 @@ SettingsDialog::SettingsDialog()
   
   connect(useFileNames,SIGNAL(toggled(bool)),updateOnAdding,SLOT(setDisabled(bool)));
   connect(useFileNames,SIGNAL(toggled(bool)),updateOnPlaying,SLOT(setDisabled(bool)));
+  connect(useFileNames,SIGNAL(toggled(bool)),labelMetadata,SLOT(setDisabled(bool)));
   
   connect(buttonDir,SIGNAL(clicked()),this,SLOT(browseDir()));
   
