@@ -15,9 +15,16 @@ public:
   void getConfig(Config* outputConfig);
   
 private:
-  QVBoxLayout* dialogLayout;
+  //QVBoxLayout* dialogLayout;
+  //QVBoxLayout* configLayout;
+#ifdef Q_WS_MAEMO
+  QHBoxLayout* configLayout;
+#else
   QVBoxLayout* configLayout;
+#endif
+  
   QHBoxLayout* tagsLayout;
+  QHBoxLayout* tagsOptLayout;
   QVBoxLayout* scrollLayout;
   QWidget* scrollW;
   
@@ -25,6 +32,7 @@ private:
   
   QGroupBox* playlistBox;
   QVBoxLayout* playlistLayout;
+  QLabel* labelMetadata;
   QButtonGroup *useTagsOrNames;
   QRadioButton* useTags;
   QRadioButton* useFileNames;
