@@ -9,7 +9,7 @@
 int main(int argc, char  * argv[])
 {
 	UPlay app(argc, argv);
-	app.setApplicationName("NecroPlayer");
+	app.setApplicationName("necroplayer");
 
 	// param	
 // 	QStringList files;
@@ -38,7 +38,10 @@ int main(int argc, char  * argv[])
 	//app.restorePlaylist();
 	
 // 	app.addMedia(files);
+	
 
 
+	
+
 	return app.exec();
 }
